Package: WWGbook
Version: 1.0.2
Date: 2022-02-28
Author: Shu Chen, Andrzej Galecki <agalecki@umich.edu>
Maintainer: Shu Chen <chenshu@umich.edu>
Title: Functions and Datasets for WWGbook
Description: Book is "Linear Mixed Models: A Practical Guide Using
        Statistical Software" published in 2006 by Chapman Hall / CRC
        Press.
Depends: R (>= 1.4.1)
License: GPL (>= 2)
URL: http://www-personal.umich.edu/~bwest/almmussp.html
LazyData: yes
NeedsCompilation: no
Packaged: 2022-03-01 22:04:46 UTC; eddyt
Repository: CRAN
Date/Publication: 2022-03-02 00:10:29 UTC
Built: R 4.4.0; ; 2024-05-08 13:31:48 UTC; unix
